#!/bin/sh

# disable variables not being referenced warning
# shellcheck disable=SC2034

# Check if we are scanning an RE image
# check_is_re_image target_image
check_is_re_image() {
    IMAGE="$1"
    # Get image name without the tag
    IMAGE_NAME=$(echo "${IMAGE}" | sed 's|:[^:/]*$||')
    if echo "${IMAGE_NAME}" | grep "re/releng" >/dev/null 2>&1; then
        # IMAGE_NAME is an RE image (not considering tags)
        return 0
    fi

    return 1
}

# check_image_base target_image base_image
# check_image_base artifactory-pub.bit9.local:5002/re/releng/photon3-go:220502_0908 artifactory-pub.bit9.local:5001/re/releng/photon3:220502_0714
check_image_base() {
    BASE_LAYER_CHAIN=$(docker inspect --format='{{.RootFS.Layers}}' "${2}" | tr -d '[],')
    TARGET_LAYER_CHAIN=$(docker inspect --format='{{.RootFS.Layers}}' "${1}" | tr -d '[],')
    if test -z "${BASE_LAYER_CHAIN}" || test -z "${TARGET_LAYER_CHAIN}"; then
        # We could not get the layers for some reason
        return 2
    fi
    # check whether the chain of base layers is contained within the target layers and return
    case "$TARGET_LAYER_CHAIN" in
    *"$BASE_LAYER_CHAIN"*)
        return 0
        ;;
    esac

    # fail if base is not a substring of target
    return 1
}

# error_msg
error_msg() {
    printf "\u001b[31;1m"
    printf "%s" "$*"
    printf "\u001b[0m\n"
}

# cleanup between images
cleanup() {
    rm "${REP_PATH_CLI}"/base_image*.json 2>/dev/null || true
    rm "${REP_PATH_CLI}"/target_image*.json 2>/dev/null || true
}

set_image_vars() {
    # Take the first argument as the IMAGE
    IMAGE_ARG=$1

    IMAGE_REGISTRY_NAME=$(echo "${IMAGE_ARG}" | cut -d'/' -f 1)

    IMAGE_REPO_NAME=$(echo "${IMAGE_ARG}" | cut -d'/' -f 2- | cut -d':' -f1 | sed 's:/:_:g')

    IMAGE_TAG=$(echo "${IMAGE_ARG}" | rev | cut -d":" -f1 | rev)

    RES_CLI="${REP_PATH_CLI}/${SCANNER}__${CI_PIPELINE_ID}__${JENKINS_BUILD_ID}__${IMAGE_REGISTRY_NAME}__${IMAGE_REPO_NAME}__${IMAGE_TAG}"

    JSON_OUTPUT="${REP_PATH_CLI}/psec__${CI_PIPELINE_ID}__${JENKINS_BUILD_ID}__${SCANNER}__${IMAGE_REGISTRY_NAME}__${IMAGE_REPO_NAME}__${IMAGE_TAG}.json"
}

# Get info from `/etc/os-release`
get_info_os() {
    # Take the first argument as the IMAGE
    IMAGE="${1}"

    # Distinguishable from what docker run might error out with
    EXIT_NOSHELL=129

    if ! docker run --rm --entrypoint /bin/sh "${IMAGE}" -c "true"; then
        echo "Could not run shell in ${IMAGE}" >&2
        return "${EXIT_NOSHELL}"
    fi

    # Using `.` instead of `source` as it might not be available for non-bash shells in OSes like Ubuntu,
    # there is no `source` available in `/bin/sh` which is in fact, dash
    docker run --rm --entrypoint /bin/sh "${IMAGE}" -c '. /etc/os-release; echo "${NAME} ${VERSION_ID}"'
    return $?
}
